@@ -1,8 +1,8 @@
 import pkg_resources
 
-import wikibaseintegrator.wdi_core
-import wikibaseintegrator.wdi_fastrun
-import wikibaseintegrator.wdi_login
+import wikibaseintegrator.wbi_core
+import wikibaseintegrator.wbi_fastrun
+import wikibaseintegrator.wbi_login
 
 try:
     __version__ = pkg_resources.get_distribution("wikibaseintegrator").version
