@@ -1,8 +1,9 @@
 from __future__ import print_function
+
+import os
 import sys
 
-from wikibaseintegrator import wdi_login
-import os
+from wikibaseintegrator import wbi_login
 
 # look for environment variables. if none set, don't do anything
 WDUSER = os.getenv("WDUSER")
@@ -11,6 +12,6 @@ WDPASS = os.getenv("WDPASS")
 
 def test_login():
     if WDUSER and WDPASS:
-        login = wdi_login.WDLogin(WDUSER, WDPASS)
+        login = wbi_login.Login(WDUSER, WDPASS)
     else:
         print("no WDUSER or WDPASS found in environment variables", file=sys.stderr)
